@@ -2,7 +2,7 @@
 function() {
   dist <- c("cau","exp","gam","gev","gld","glo","gno",
             "gpa","gum","kap","kur","ln3","nor","pe3","ray",
-            "revgum","wak","wei");
+            "revgum","rice","wak","wei");
   return(dist)
-} 
+}
 
